==> mastapy-14.0.0.tar.gz: mastapy-14.0.0/mastapy/_private/utility/units_and_measurements/measurements/_1723.py <==
"""LinearAngularStiffnessCrossTerm"""

from __future__ import annotations

from typing import ClassVar, TYPE_CHECKING

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655

_LINEAR_ANGULAR_STIFFNESS_CROSS_TERM = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements",
    "LinearAngularStiffnessCrossTerm",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="LinearAngularStiffnessCrossTerm")
    CastSelf = TypeVar(
        "CastSelf",
        bound="LinearAngularStiffnessCrossTerm._Cast_LinearAngularStiffnessCrossTerm",
    )


__docformat__ = "restructuredtext en"
__all__ = ("LinearAngularStiffnessCrossTerm",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LinearAngularStiffnessCrossTerm:
    """Special nested class for casting LinearAngularStiffnessCrossTerm to subclasses."""

    __parent__: "LinearAngularStiffnessCrossTerm"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def linear_angular_stiffness_cross_term(
        self: "CastSelf",
    ) -> "LinearAngularStiffnessCrossTerm":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class LinearAngularStiffnessCrossTerm(_1655.MeasurementBase):
    """LinearAngularStiffnessCrossTerm

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LINEAR_ANGULAR_STIFFNESS_CROSS_TERM

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_LinearAngularStiffnessCrossTerm":
        """Cast to another type.

        Returns:
            _Cast_LinearAngularStiffnessCrossTerm
        """
        return _Cast_LinearAngularStiffnessCrossTerm(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1723.py <==
"""Jerk"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_JERK = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Jerk"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Jerk")
    CastSelf = TypeVar("CastSelf", bound="Jerk._Cast_Jerk")


__docformat__ = "restructuredtext en"
__all__ = ("Jerk",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Jerk:
    """Special nested class for casting Jerk to subclasses."""

    __parent__: "Jerk"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def jerk(self: "CastSelf") -> "Jerk":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Jerk(_1666.MeasurementBase):
    """Jerk

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _JERK

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Jerk":
        """Cast to another type.

        Returns:
            _Cast_Jerk
        """
        return _Cast_Jerk(self)
